// TestConstants.cpp
// Test the math constants #defined in sofam.h.
// Copyright 2015 Paul S. Hirose

// revision history
// 2014-07-30  Math constants all check good.
// 2015-08-27  Rewrote TestConstants() to simpler form.
// 2017-09-06  Minor cleanups for SofaJpl 2.1.


#include "stdafx.h"
#include <stdexcept>
#include <cmath>

#include "sofam1704.h"


#define DECLSPEC extern "C" __declspec(dllexport)

DECLSPEC void TestConstants();


#ifdef _DEBUG


// Throw an exception if test value doesn't match the supplied correct value within a
// given tolerance.
void equalsApprox(double testValue, double correctValue, double tolerance, const char *message) {
	if (correctValue != 0.0) {
		if (abs(testValue - correctValue) / correctValue > tolerance)
			throw std::runtime_error(message);
	} else
		if (abs(testValue - correctValue) > tolerance)
			throw std::runtime_error(message);
}


// The function that tests the math constants in sofam.h. Returns nonzero and an error message
// if out of tolerance.
void TestConstants() {
	double pi = std::acos(-1.0);
	double tolerance = 1e-15;		// max permissible relative error
	equalsApprox(DPI, pi, tolerance, "DPI");
	equalsApprox(D2PI, 2.0*pi, tolerance, "D2PI");
	equalsApprox(DR2D, 180.0 / pi, tolerance, "DR2D");		// deg per rad
	equalsApprox(DD2R, pi / 180.0, tolerance, "DD2R");		// rad per deg
	equalsApprox(DR2AS, (180.0 * 3600) / pi, tolerance, "DR2AS");	// arcsec per rad
	equalsApprox(DAS2R, pi / (180.0 * 3600), tolerance, " DAS2R");	// rad per arcsec
	equalsApprox(DS2R, pi / (12.0 * 3600), tolerance, "DS2R");	// rad per time sec
	equalsApprox(TURNAS, 360.0 * 3600, tolerance, "TURNAS");	// arcsec per circle
	equalsApprox(DMAS2R, pi / (180 * 3.6e6), tolerance, "DMAS2R");	// rad per mas

	// This should fail.
	// equalsApprox(2.718, exp(1.0), 1e-6, "Exception thrown as expected.");
}


// end debug code
#endif
